Learn R Programming

scenfire (version 0.1.0)

flp20_to_raster: Convert processed FLP data to raster format and calculate conditional annual burn probability

Description

Filters a data frame of fire data based on a flame length threshold, groups by spatial position (`XPos`, `YPos`), and summarizes it into conditional annual burning probability (CBP) estimates and mean flame length (FL_mean).

Usage

flp20_to_raster(df, fl_threshold, selected_surf, reference_surface, r_ref)

Value

A list containing two raster objects: `CBP`, `CFL` and `ID_fires`.

Arguments

df

A data frame processed by `flp20_to_df` or `flp20_to_bp_df`.

fl_threshold

A numeric value representing the minimum flame length (FL).

selected_surf

A data frame or list containing a `size` column.

reference_surface

A numeric value representing a reference surface area.

r_ref

A terra SpatRaster object.