Filters a data frame of fire data based on a flame length threshold, groups by spatial position (`XPos`, `YPos`), and summarizes it into conditional annual burning probability (CBP) estimates and mean flame length (FL_mean).
flp20_to_raster(df, fl_threshold, selected_surf, reference_surface, r_ref)A list containing two raster objects: `CBP`, `CFL` and `ID_fires`.
A data frame processed by `flp20_to_df` or `flp20_to_bp_df`.
A numeric value representing the minimum flame length (FL).
A data frame or list containing a `size` column.
A numeric value representing a reference surface area.
A terra SpatRaster object.